@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -36,15 +36,19 @@
 
 /**
  * Structure for Content-Type headers.
- * @defvar osip_content_type_t
+ * @var osip_content_type_t
  */
   typedef struct osip_content_type osip_content_type_t;
 
+/**
+ * Definition of the Content-Type header.
+ * @struct osip_content_type
+ */
   struct osip_content_type
   {
-    char *type;
-    char *subtype;
-    osip_list_t *gen_params;
+    char *type;                 /**< Type of attachement */
+    char *subtype;              /**< Sub-Type of attachement */
+    osip_list_t gen_params;     /**< Content-Type parameters */
   };
 
 #ifdef __cplusplus
@@ -88,14 +92,14 @@ extern "C"
  * @param name The token name.
  * @param value The token value.
  */
-#define osip_content_type_param_add(header,name,value)  osip_generic_param_add((header)->gen_params,name,value)
+#define osip_content_type_param_add(header,name,value)  osip_generic_param_add((&(header)->gen_params),name,value)
 /**
  * Find a header parameter in a Content-Type element.
  * @param header The element to work on.
  * @param name The token name to search.
  * @param dest A pointer on the element found.
  */
-#define osip_content_type_param_get_byname(header,name,dest) osip_generic_param_get_byname((header)->gen_params,name,dest)
+#define osip_content_type_param_get_byname(header,name,dest) osip_generic_param_get_byname((&(header)->gen_params),name,dest)
 
 
 #ifdef __cplusplus
