@@ -147,9 +147,9 @@ osip_accept_encoding_to_str(const osip_accept_encoding_t * accept_encoding,
 			tmp = buf;
 			tmp = tmp + strlen(tmp);
 			if (u_param->gvalue == NULL)
-				sprintf(tmp, ";%s", u_param->gname);
+				snprintf(tmp, len - (tmp-buf), ";%s", u_param->gname);
 			else
-				sprintf(tmp, ";%s=%s", u_param->gname, u_param->gvalue);
+				snprintf(tmp, len - (tmp-buf), ";%s=%s", u_param->gname, u_param->gvalue);
 			pos++;
 		}
 	}
