@@ -27,42 +27,40 @@
 
 #ifndef MINISIZE
 
-int
-osip_message_set_accept_language (osip_message_t * sip, const char *hvalue)
+int osip_message_set_accept_language(osip_message_t * sip, const char *hvalue)
 {
-  osip_accept_language_t *accept_language;
-  int i;
+	osip_accept_language_t *accept_language;
+	int i;
 
-  if (hvalue == NULL || hvalue[0] == '\0')
-    return OSIP_SUCCESS;
+	if (hvalue == NULL || hvalue[0] == '\0')
+		return OSIP_SUCCESS;
 
-  i = osip_accept_language_init (&accept_language);
-  if (i != 0)
-    return i;
-  i = osip_accept_language_parse (accept_language, hvalue);
-  if (i != 0)
-    {
-      osip_accept_language_free (accept_language);
-      return i;
-    }
-  sip->message_property = 2;
-  osip_list_add (&sip->accept_languages, accept_language, -1);
-  return OSIP_SUCCESS;
+	i = osip_accept_language_init(&accept_language);
+	if (i != 0)
+		return i;
+	i = osip_accept_language_parse(accept_language, hvalue);
+	if (i != 0) {
+		osip_accept_language_free(accept_language);
+		return i;
+	}
+	sip->message_property = 2;
+	osip_list_add(&sip->accept_languages, accept_language, -1);
+	return OSIP_SUCCESS;
 }
 
 int
-osip_message_get_accept_language (const osip_message_t * sip, int pos,
-                                  osip_accept_language_t ** dest)
+osip_message_get_accept_language(const osip_message_t * sip, int pos,
+								 osip_accept_language_t ** dest)
 {
-  osip_accept_language_t *accept_language;
+	osip_accept_language_t *accept_language;
 
-  *dest = NULL;
-  if (osip_list_size (&sip->accept_languages) <= pos)
-    return OSIP_UNDEFINED_ERROR;     /* does not exist */
-  accept_language =
-    (osip_accept_language_t *) osip_list_get (&sip->accept_languages, pos);
-  *dest = accept_language;
-  return pos;
+	*dest = NULL;
+	if (osip_list_size(&sip->accept_languages) <= pos)
+		return OSIP_UNDEFINED_ERROR;	/* does not exist */
+	accept_language =
+		(osip_accept_language_t *) osip_list_get(&sip->accept_languages, pos);
+	*dest = accept_language;
+	return pos;
 }
 
 #endif
