@@ -27,41 +27,39 @@
 
 #ifndef MINISIZE
 
-int
-osip_message_set_alert_info (osip_message_t * sip, const char *hvalue)
+int osip_message_set_alert_info(osip_message_t * sip, const char *hvalue)
 {
-  osip_alert_info_t *alert_info;
-  int i;
+	osip_alert_info_t *alert_info;
+	int i;
 
-  if (hvalue == NULL || hvalue[0] == '\0')
-    return OSIP_SUCCESS;
+	if (hvalue == NULL || hvalue[0] == '\0')
+		return OSIP_SUCCESS;
 
-  i = osip_alert_info_init (&alert_info);
-  if (i != 0)
-    return i;
-  i = osip_alert_info_parse (alert_info, hvalue);
-  if (i != 0)
-    {
-      osip_alert_info_free (alert_info);
-      return i;
-    }
-  sip->message_property = 2;
-  osip_list_add (&sip->alert_infos, alert_info, -1);
-  return OSIP_SUCCESS;
+	i = osip_alert_info_init(&alert_info);
+	if (i != 0)
+		return i;
+	i = osip_alert_info_parse(alert_info, hvalue);
+	if (i != 0) {
+		osip_alert_info_free(alert_info);
+		return i;
+	}
+	sip->message_property = 2;
+	osip_list_add(&sip->alert_infos, alert_info, -1);
+	return OSIP_SUCCESS;
 }
 
 int
-osip_message_get_alert_info (const osip_message_t * sip, int pos,
-                             osip_alert_info_t ** dest)
+osip_message_get_alert_info(const osip_message_t * sip, int pos,
+							osip_alert_info_t ** dest)
 {
-  osip_alert_info_t *alert_info;
+	osip_alert_info_t *alert_info;
 
-  *dest = NULL;
-  if (osip_list_size (&sip->alert_infos) <= pos)
-    return OSIP_UNDEFINED_ERROR;     /* does not exist */
-  alert_info = (osip_alert_info_t *) osip_list_get (&sip->alert_infos, pos);
-  *dest = alert_info;
-  return pos;
+	*dest = NULL;
+	if (osip_list_size(&sip->alert_infos) <= pos)
+		return OSIP_UNDEFINED_ERROR;	/* does not exist */
+	alert_info = (osip_alert_info_t *) osip_list_get(&sip->alert_infos, pos);
+	*dest = alert_info;
+	return pos;
 }
 
 #endif
