@@ -189,7 +189,7 @@ int osip_content_type_to_str(const osip_content_type_t * content_type, char **de
 				len = tmp_len;
 				tmp = buf + strlen(buf);
 			}
-			sprintf(tmp, "; %s=%s", u_param->gname, u_param->gvalue);
+			snprintf(tmp, len - (tmp - buf), "; %s=%s", u_param->gname, u_param->gvalue);
 			tmp = tmp + strlen(tmp);
 			pos++;
 		}
@@ -246,7 +246,7 @@ osip_content_type_clone(const osip_content_type_t * ctt,
 			i = osip_generic_param_clone(u_param, &dest_param);
 			if (i != 0) {
 				osip_content_type_free(ct);
-				osip_free(ct);
+				//osip_free(ct);
 				return i;
 			}
 			osip_list_add(&ct->gen_params, dest_param, -1);
