@@ -143,7 +143,7 @@ int osip_cseq_to_str(const osip_cseq_t * cseq, char **dest)
 	*dest = (char *) osip_malloc(len);
 	if (*dest == NULL)
 		return OSIP_NOMEM;
-	sprintf(*dest, "%s %s", cseq->number, cseq->method);
+	snprintf(*dest, len, "%s %s", cseq->number, cseq->method);
 	return OSIP_SUCCESS;
 }
 
