@@ -301,9 +301,9 @@ int osip_from_to_str(const osip_from_t * from, char **dest)
 			tmp = buf;
 			tmp = tmp + strlen(tmp);
 			if (u_param->gvalue == NULL)
-				sprintf(tmp, ";%s", u_param->gname);
+				snprintf(tmp, len - (tmp-buf), ";%s", u_param->gname);
 			else
-				sprintf(tmp, ";%s=%s", u_param->gname, u_param->gvalue);
+				snprintf(tmp, len - (tmp-buf), ";%s=%s", u_param->gname, u_param->gvalue);
 			pos++;
 		}
 	}
